@@ -45,6 +45,7 @@ __all__ = (
     "TriggerTypeType",
     "WebhookAuthenticationTypeType",
     "ServiceName",
+    "PaginatorName",
 )
 
 
@@ -373,3 +374,11 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal[
+    "list_action_executions",
+    "list_action_types",
+    "list_pipeline_executions",
+    "list_pipelines",
+    "list_tags_for_resource",
+    "list_webhooks",
+]
